@@ -1,21 +1,42 @@
 """Configuration of logging"""
 import logging
 from sys import stdout
+from typing import Optional
 
 from loguru import logger
 
 
-def setup_logging(error_file: bool = False) -> None:
+def setup_logging(
+    console_log_level: str = "INFO",
+    log_file: Optional[str] = None,
+    file_log_level: str = "ERROR",
+) -> None:
     """Setup logging configuration. intercepts standard logging and outputs errors to
     a file.
 
     Args:
-        error_file (bool): Whether to output errors.log file. Defaults to False.
+        console_log_level (str): Log level to use for console output. Defaults to INFO.
+        log_file (Optional[str]): Path of log file. Defaults to None (No log file).
+        file_log_level (str): Log level to use for console output. Defaults to ERROR.
 
     Returns:
         None
     """
-    logger.add(stdout, colorize=True, backtrace=True, diagnose=True)
+    logger.add(
+        stdout,
+        level=console_log_level,
+        colorize=True,
+        backtrace=True,
+        diagnose=True,
+    )
+    if log_file:
+        logger.add(
+            log_file,
+            level=file_log_level,
+            mode="w",
+            backtrace=True,
+            diagnose=True,
+        )
 
     class InterceptHandler(logging.Handler):
         def emit(self, record):
@@ -38,12 +59,4 @@ def setup_logging(error_file: bool = False) -> None:
                 exception=record.exc_info,
             ).log(level, record.getMessage())
 
-    if error_file:
-        logger.add(
-            "errors.log",
-            level="ERROR",
-            mode="w",
-            backtrace=True,
-            diagnose=True,
-        )
     logging.basicConfig(handlers=[InterceptHandler()], level=logging.NOTSET)
